@@ -6,20 +6,20 @@ use std::io::Write;
 
 use syn;
 
-use bindgen::config::{Config, Language, LayoutConfig};
-use bindgen::declarationtyperesolver::DeclarationTypeResolver;
-use bindgen::dependencies::Dependencies;
-use bindgen::ir::{
+use crate::bindgen::config::{Config, Language, LayoutConfig};
+use crate::bindgen::declarationtyperesolver::DeclarationTypeResolver;
+use crate::bindgen::dependencies::Dependencies;
+use crate::bindgen::ir::{
     AnnotationSet, Cfg, ConditionWrite, Constant, Documentation, GenericParams, Item,
     ItemContainer, Path, Repr, ReprAlign, ReprStyle, ToCondition, Type, Typedef,
 };
-use bindgen::library::Library;
-use bindgen::mangle;
-use bindgen::monomorph::Monomorphs;
-use bindgen::rename::{IdentifierType, RenameRule};
-use bindgen::reserved;
-use bindgen::utilities::{find_first_some, IterHelpers};
-use bindgen::writer::{ListType, Source, SourceWriter};
+use crate::bindgen::library::Library;
+use crate::bindgen::mangle;
+use crate::bindgen::monomorph::Monomorphs;
+use crate::bindgen::rename::{IdentifierType, RenameRule};
+use crate::bindgen::reserved;
+use crate::bindgen::utilities::{find_first_some, IterHelpers};
+use crate::bindgen::writer::{ListType, Source, SourceWriter};
 
 #[derive(Debug, Clone)]
 pub struct Struct {
@@ -65,6 +65,8 @@ impl Struct {
             }
         };
 
+        let path = Path::new(item.ident.to_string());
+
         // Ensure we can safely represent the struct given the configuration.
         if let Some(align) = repr.align {
             layout_config.ensure_safe_to_represent(&align)?;
@@ -76,14 +78,15 @@ impl Struct {
                 let out = fields
                     .named
                     .iter()
-                    .try_skip_map(|x| x.as_ident_and_type())?;
+                    .try_skip_map(|x| x.as_ident_and_type(&path))?;
                 (out, false)
             }
             syn::Fields::Unnamed(ref fields) => {
                 let mut out = Vec::new();
                 let mut current = 0;
                 for field in fields.unnamed.iter() {
-                    if let Some(x) = Type::load(&field.ty)? {
+                    if let Some(mut x) = Type::load(&field.ty)? {
+                        x.replace_self_with(&path);
                         out.push((format!("{}", current), x, Documentation::load(&field.attrs)));
                         current += 1;
                     }
@@ -96,7 +99,7 @@ impl Struct {
         let is_enum_variant_body = false;
 
         Ok(Struct::new(
-            Path::new(item.ident.to_string()),
+            path,
             GenericParams::new(&item.generics),
             fields,
             is_tagged,
@@ -403,7 +406,7 @@ impl Source for Struct {
             return;
         }
 
-        let condition = (&self.cfg).to_condition(config);
+        let condition = self.cfg.to_condition(config);
         condition.write_before(config, out);
 
         self.documentation.write(config, out);
@@ -452,6 +455,12 @@ impl Source for Struct {
 
         out.open_brace();
 
+        // Emit the pre_body section, if relevant
+        if let Some(body) = config.export.pre_body(&self.path) {
+            out.write_raw_block(body);
+            out.new_line();
+        }
+
         if config.documentation {
             out.write_vertical_source_list(&self.fields, ListType::Cap(";"));
         } else {
@@ -600,7 +609,9 @@ impl Source for Struct {
             }
         }
 
-        if let Some(body) = config.export.extra_body(&self.path) {
+        // Emit the post_body section, if relevant
+        if let Some(body) = config.export.post_body(&self.path) {
+            out.new_line();
             out.write_raw_block(body);
         }
 
@@ -631,11 +642,17 @@ impl Source for Struct {
 }
 
 pub trait SynFieldHelpers {
-    fn as_ident_and_type(&self) -> Result<Option<(String, Type, Documentation)>, String>;
+    fn as_ident_and_type(
+        &self,
+        self_path: &Path,
+    ) -> Result<Option<(String, Type, Documentation)>, String>;
 }
 
 impl SynFieldHelpers for syn::Field {
-    fn as_ident_and_type(&self) -> Result<Option<(String, Type, Documentation)>, String> {
+    fn as_ident_and_type(
+        &self,
+        self_path: &Path,
+    ) -> Result<Option<(String, Type, Documentation)>, String> {
         let ident = self
             .ident
             .as_ref()
@@ -643,7 +660,8 @@ impl SynFieldHelpers for syn::Field {
             .clone();
         let converted_ty = Type::load(&self.ty)?;
 
-        if let Some(x) = converted_ty {
+        if let Some(mut x) = converted_ty {
+            x.replace_self_with(self_path);
             Ok(Some((
                 ident.to_string(),
                 x,
