@@ -24,7 +24,7 @@ use clap::{App, Arg, ArgMatches};
 mod bindgen;
 mod logging;
 
-use bindgen::{Bindings, Builder, Cargo, Config, Error, Language, Style};
+use crate::bindgen::{Bindings, Builder, Cargo, Config, Error, Language, Style};
 
 fn apply_config_overrides<'a>(config: &mut Config, matches: &ArgMatches<'a>) {
     // We allow specifying a language to override the config default. This is
@@ -258,6 +258,7 @@ fn main() {
             let changed = bindings.write_to_file(file);
 
             if matches.is_present("verify") && changed {
+                error!("Bindings changed: {}", file);
                 std::process::exit(2);
             }
         }
